@@ -6,16 +6,20 @@ AbstractParser <- R6::R6Class(
                             main_node = NULL,
                             secondary_node = NULL,
                             id = NULL) {
-        private$tibble_name  <- tibble_name
-        private$object_node <- object_node
-        private$main_node <- main_node
+        private$tibble_name    <- tibble_name
+        private$object_node    <- object_node
+        private$main_node      <- main_node
         private$secondary_node <- secondary_node
-        private$id <- id
+        private$id             <- id
 
       },
       parse = function() {
-        parsed_tbl <- private$parse_record()
-        as_tibble(parsed_tbl)
+        parsed_tbl        <- private$parse_record()
+        parsed_tbl        <- as_tibble(parsed_tbl)
+        names(parsed_tbl) <- gsub(pattern     = "-",
+                                  replacement = "_",
+                                  x           =  names(parsed_tbl))
+        parsed_tbl
       }
     ),
     private = list(
