@@ -26,6 +26,10 @@ DrugElementsParser <- R6::R6Class(
           parsed_tbl <- rename(parsed_tbl, db_salt_id = "drugbank-id")
         }
 
+        if (private$main_node == "drug-interactions") {
+          parsed_tbl <- rename(parsed_tbl, target_drugbank_id = "drugbank-id")
+        }
+
         if ("parent_key" %in% names(parsed_tbl)) {
           parsed_tbl <- rename(parsed_tbl, drugbank_id = parent_key)
         }
